aboutsummaryrefslogtreecommitdiff
path: root/R/create-docs.sh
diff options
context:
space:
mode:
Diffstat (limited to 'R/create-docs.sh')
-rwxr-xr-xR/create-docs.sh11
1 files changed, 9 insertions, 2 deletions
diff --git a/R/create-docs.sh b/R/create-docs.sh
index d2ae160b50..0dfba22463 100755
--- a/R/create-docs.sh
+++ b/R/create-docs.sh
@@ -17,11 +17,13 @@
# limitations under the License.
#
# Script to create API docs for SparkR
# This requires `devtools` and `knitr` to be installed on the machine.
# After running this script the html docs can be found in
# $SPARK_HOME/R/pkg/html
+# The vignettes can be found in
+# $SPARK_HOME/R/pkg/vignettes/sparkr_vignettes.html
set -o pipefail
set -e
@@ -43,4 +45,9 @@ Rscript -e 'libDir <- "../../lib"; library(SparkR, lib.loc=libDir); library(knit
popd
+# render creates SparkR vignettes
+Rscript -e 'library(rmarkdown); paths <- .libPaths(); .libPaths(c("lib", paths)); Sys.setenv(SPARK_HOME=tools::file_path_as_absolute("..")); render("pkg/vignettes/sparkr-vignettes.Rmd"); .libPaths(paths)'
+
+find pkg/vignettes/. -not -name '.' -not -name '*.Rmd' -not -name '*.md' -not -name '*.pdf' -not -name '*.html' -delete
+
popd
@@ -17,11 +17,13 @@
# limitations under the License.
#
-# Script to create API docs for SparkR
-# This requires `devtools` and `knitr` to be installed on the machine.
+# Script to create API docs and vignettes for SparkR
+# This requires `devtools`, `knitr` and `rmarkdown` to be installed on the machine.
# After running this script the html docs can be found in
# $SPARK_HOME/R/pkg/html